@@ -1,14 +1,14 @@
 package Email::Sender::Transport::SMTP::TLS;
 
 BEGIN {
-    $Email::Sender::Transport::SMTP::TLS::VERSION = '0.08';
+    $Email::Sender::Transport::SMTP::TLS::VERSION = '0.09';
 }
 
 # ABSTRACT: Email::Sender with L<Net::SMTP::TLS> (Eg. Gmail)
 
 use Moose 0.90;
 
-use Net::SMTP::TLS;
+use Net::SMTP::TLS::ButMaintained;
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
 use Email::Sender::Util;
@@ -40,7 +40,7 @@ sub _smtp_client {
 
     my $smtp;
     eval {
-        $smtp = Net::SMTP::TLS->new(
+        $smtp = Net::SMTP::TLS::ButMaintained->new(
             $self->host,
             Port     => $self->port,
             User     => $self->username,
@@ -169,7 +169,7 @@ Email::Sender::Transport::SMTP::TLS - Email::Sender with L<Net::SMTP::TLS> (Eg.
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
